OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Get ekki skrifað í \"config\" möppuna!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í stillingamöppuna",
    "See %s" : "Skoðaðu %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Þetta er venjulega hægt að laga ef %sgefur vefþjóninum skrifréttindi í stillingamöppuna%s.",
    "Sample configuration detected" : "Fann sýnisuppsetningu",
    "PHP %s or higher is required." : "Krafist er PHP %s eða hærra.",
    "PHP with a version lower than %s is required." : "Krafist er PHP útgáfu %s eða lægri.",
    "%sbit or higher PHP required." : "Krafist er PHP %sbita eða hærra.",
    "Following databases are supported: %s" : "Eftirfarandi gagnagrunnar eru studdir: %s",
    "The command line tool %s could not be found" : "Skipanalínutólið \"%s\" fannst ekki",
    "The library %s is not available." : "Aðgerðasafnið %s er ekki tiltækt.",
    "Library %s with a version higher than %s is required - available version %s." : "Krafist er aðgerðasafns %s með útgáfu hærri en %s - tiltæk útgáfa er %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Krafist er aðgerðasafns %s með útgáfu lægri en %s - tiltæk útgáfa er %s.",
    "Following platforms are supported: %s" : "Eftirfarandi stýrikerfi eru studd: %s",
    "ownCloud %s or higher is required." : "Krafist er Nextcloud %s eða hærra.",
    "ownCloud %s or lower is required." : "Krafist er Nextcloud %s eða lægra.",
    "Unknown filetype" : "Óþekkt skráategund",
    "Invalid image" : "Ógild mynd",
    "Avatar image is not square" : "Auðkennismynd er ekki ferningslaga",
    "today" : "í dag",
    "yesterday" : "í gær",
    "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
    "last month" : "í síðasta mánuði",
    "_%n month ago_::_%n months ago_" : ["fyrir %n mánuði","fyrir %n mánuðum"],
    "last year" : "síðasta ári",
    "_%n year ago_::_%n years ago_" : ["fyrir %n degi síðan","fyrir %n árum síðan"],
    "_%n hour ago_::_%n hours ago_" : ["fyrir %n klukkustund síðan","fyrir %n klukkustundum síðan"],
    "_%n minute ago_::_%n minutes ago_" : ["fyrir %n mínútu síðan","fyrir %n mínútum síðan"],
    "seconds ago" : "sekúndum síðan",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Eining með auðkenni: %s er ekki til. Virkjaðu hana í forritastillingum eða hafðu samband við kerfisstjóra.",
    "Builtin" : "Innbyggt",
    "None" : "Ekkert",
    "Username and password" : "Notandanafn og lykilorð",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Log-in credentials, save in session" : "Innskráningarauðkenni, vista í setu",
    "Empty filename is not allowed" : "Autt skráarheiti er ekki leyft.",
    "Dot files are not allowed" : "Skrár með punkti eru ekki leyfðar",
    "4-byte characters are not supported in file names" : "4-bæta stafir eru ekki leyfilegir í skráaheitum",
    "File name is a reserved word" : "Skráarheiti er þegar frátekið orð",
    "File name contains at least one invalid character" : "Skráarheitið inniheldur að minnsta kosti einn ógildan staf",
    "File name is too long" : "Skráarheiti er of langt",
    "App directory already exists" : "Forritsmappan er þegar til",
    "Can't create app folder. Please fix permissions. %s" : "Gat ekki búið til forritsmöppu. Lagaðu aðgangsheimildir. %s",
    "Archive does not contain a directory named %s" : "Safnskráin inniheldur ekki möppu með heitinu %s",
    "No source specified when installing app" : "Enginn uppruni tilgreindur þegar forrit var sett upp",
    "No href specified when installing app from http" : "Ekkert href tilgreint þegar forrit var sett upp í gegnum http",
    "No path specified when installing app from local file" : "Engin slóð tilgreind þegar forrit var sett upp úr staðværri skrá",
    "Archives of type %s are not supported" : "Safnskrár af gerðinni %s eru ekki studdar",
    "Failed to open archive when installing app" : "Mistókst að opna safnskrá við uppsetningu forrits",
    "App does not provide an info.xml file" : "Forritið er ekki með neina info.xml skrá",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Ekki var hægt að setja upp forritið vegna þess að það er ekki samhæft þessari útgáfu ownCloud",
    "Apps" : "Forrit",
    "General" : "Almennt",
    "Storage" : "Gagnageymsla",
    "Security" : "Öryggi",
    "User Authentication" : "Auðkenning notanda",
    "Encryption" : "Dulritun",
    "Workflows & Tags" : "Verkferli og merki",
    "Sharing" : "Deiling",
    "Search" : "Leita",
    "Updates" : "Uppfærslur",
    "Help & Tips" : "Hjálp & ábendingar",
    "Additional" : "Aukalegt",
    "%s enter the database username and name." : "%s settu inn notandanafn og nafn á gagnagrunni.",
    "%s enter the database username." : "%s settu inn notandanafn í gagnagrunni.",
    "%s enter the database name." : "%s settu inn nafn á gagnagrunni.",
    "%s you may not use dots in the database name" : "%s þú mátt ekki nota punkta í nafni á gagnagrunni",
    "Oracle connection could not be established" : "Ekki tókst að koma tengingu á við Oracle",
    "Oracle username and/or password not valid" : "Notandanafn eða lykilorð Oracle er ekki gilt",
    "DB Error: \"%s\"" : "Gagnagrunnsvilla: \"%s\"",
    "Offending command was: \"%s\"" : "Saknæma skipunin var: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Þú verður að setja inn fyrirliggjandi notandaaðgang eða kerfisstjóra.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Saknæma skipunin var: \"%s\", nafn: %s, lykilorð: %s",
    "PostgreSQL username and/or password not valid" : "Notandanafn eða lykilorð PostgreSQL er ekki gilt",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X er ekki stutt og %s mun ekki vinna eðlilega á þessu stýrikerfi. Notaðu þetta því á þína eigin ábyrgð! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Fyrir bestu útkomu ættirðu að íhuga að nota GNU/Linux þjón í staðinn.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Það lítur út eins og þessi %s uppsetning sé að keyra á 32-bita PHP umhverfi og að open_basedir hafi verið stillt í php.ini. Þetta mun valda vandamálum með skrár stærri en 4 GB og er stranglega mælt gegn því að þetta sé gert.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjarlægðu stillinguna open_basedir úr php.ini eða skiptu yfir í 64-bita PHP.",
    "Set an admin username." : "Stilltu notandanafn kerfisstjóra.",
    "Set an admin password." : "Stilltu lykilorð kerfisstjóra.",
    "Can't create or write into the data directory %s" : "Gat ekki búið til eða skrifað í gagnamöppuna %s",
    "Invalid Federated Cloud ID" : "Ógilt skýjasambandsauðkenni (Federated Cloud ID)",
    "%s shared »%s« with you" : "%s deildi »%s« með þér",
    "%s via %s" : "%s með %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Deiling %s mistókst, því bakvinnslukerfið leyfir ekki sameignir af gerðinni %i",
    "Sharing %s failed, because the file does not exist" : "Deiling %s mistókst, því skráin er ekki til",
    "You are not allowed to share %s" : "Þú hefur ekki heimild til að deila %s",
    "Sharing %s failed, because you can not share with yourself" : "Deiling %s mistókst, því þú getur ekki deilt með sjálfum þér",
    "Sharing %s failed, because the user %s does not exist" : "Deiling %s mistókst, því notandinn %s er ekki til",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Deiling %s mistókst, því notandinn %s er ekki meðlimur í neinum hópi sem %s er meðlimur í",
    "Sharing %s failed, because this item is already shared with %s" : "Deiling %s mistókst, því þessu atriði er þegar deilt með %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Deiling %s mistókst, því þessu atriði er þegar deilt með notandanum %s",
    "Sharing %s failed, because the group %s does not exist" : "Deiling %s mistókst, því hópurinn %s er ekki til",
    "Sharing %s failed, because %s is not a member of the group %s" : "Deiling %s mistókst, því %s er ekki meðlimur í hópnum %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Þú verður að setja inn lykilorð til að útbúa opinberan tengil, aðeins verndaðir tenglar eru leyfðir",
    "Sharing %s failed, because sharing with links is not allowed" : "Deiling %s mistókst, því deiling með tenglum er ekki leyfð",
    "Not allowed to create a federated share with the same user" : "Ekki er heimilt að búa til skýjasambandssameign með sama notanda",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deiling %s mistókst, gat ekki fundið %s, hugsanlega er þjónninn ekki tiltækur í augnablikinu.",
    "Share type %s is not valid for %s" : "Deiling af gerðinni %s er ekki gild fyrir %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Stilling heimilda fyrir %s mistókst, því heimildirnar eru rétthærri en heimildir til handa %s",
    "Setting permissions for %s failed, because the item was not found" : "Stilling heimilda fyrir %s mistókst, því atriðið fannst ekki",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Get ekki stillt gildistímann. Sameignir geta ekki runnið út síðar en %s eftir að þeim hefur verið deilt",
    "Cannot set expiration date. Expiration date is in the past" : "Get ekki stillt gildistímann. Gildistíminn er þegar runninn út",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Get ekki hreinsað út gildistímann. Ætlast er til þess að sameignir hafi ákveðinn gildistíma.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Deilingarbakendinn %s verður að vera settur upp fyrir viðmótið OCP\\Share_Backend",
    "Sharing backend %s not found" : "Deilingarbakendinn %s fannst ekki",
    "Sharing backend for %s not found" : "Deilingarbakendi fyrir %s fannst ekki",
    "Sharing failed, because the user %s is the original sharer" : "Deiling mistókst, því notandinn %s er upprunalegur deilandi",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deiling %s mistókst, því heimildirnar eru rétthærri en heimildir til handa %s",
    "Sharing %s failed, because resharing is not allowed" : "Deiling %s mistókst, því endurdeiling er ekki leyfð",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deiling %s mistókst, því bakvinnslukerfið fyrir %s fann ekki upptök þess",
    "Sharing %s failed, because the file could not be found in the file cache" : "Deiling %s mistókst, því skráin fannst ekki í skyndiminni skráa",
    "Cannot increase permissions of %s" : "Get ekki aukið aðgangsheimildir %s",
    "Files can't be shared with delete permissions" : "Ekki er hægt að deila skrá með eyða-heimildum",
    "Files can't be shared with create permissions" : "Ekki er hægt að deila skrá með búa-til-heimildum",
    "Expiration date is in the past" : "Gildistíminn er þegar runninn út",
    "Cannot set expiration date more than %s days in the future" : "Ekki er hægt að setja lokadagsetningu meira en %s daga fram í tímann",
    "Could not find category \"%s\"" : "Fann ekki flokkinn \"%s\"",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Einungis eru leyfilegir eftirfarandi stafir í notandanafni: \"a-z\", \"A-Z\", \"0-9\", og \"_.@-'\"",
    "A valid username must be provided" : "Skráðu inn gilt notandanafn",
    "Username contains whitespace at the beginning or at the end" : "Notandanafnið inniheldur orðabil í upphafi eða enda",
    "A valid password must be provided" : "Skráðu inn gilt lykilorð",
    "The username is already being used" : "Notandanafnið er þegar í notkun",
    "Login canceled by app" : "Forrit hætti við innskráningu",
    "User disabled" : "Notandi óvirkur",
    "Help" : "Hjálp",
    "Settings" : "Stillingar",
    "Users" : "Notendur",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Ekki var hægt að setja upp \"%s\" forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar: %s",
    "web services under your control" : "vefþjónusta undir þinni stjórn",
    "File is currently busy, please try again later" : "Skráin er upptekin í augnablikinu, reyndu aftur síðar",
    "Can't read file" : "Get ekki lesið skrána",
    "Application is not enabled" : "Forrit ekki virkt",
    "Authentication error" : "Villa við auðkenningu",
    "Token expired. Please reload page." : "Kenniteikn er útrunnið. Þú ættir að hlaða síðunni aftur inn.",
    "Unknown user" : "Óþekktur notandi",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Engir reklar fyrir gagnagrunn eru uppsettir (sqlite, mysql eða postgresql).",
    "Cannot write into \"config\" directory" : "Get ekki skrifað í \"config\" möppuna",
    "Cannot write into \"apps\" directory" : "Get ekki skrifað í \"apps\" möppuna",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Þetta er venjulega hægt að laga ef %sgefur vefþjóninum skrifréttindi í forritamöppuna%s eða gerir forritabúðina óvirka í stillingaskránni.",
    "Cannot create \"data\" directory" : "Get ekki búið til \"data\" möppu",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Þetta er venjulega hægt að laga ef <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">gefur vefþjóninum skrifréttindi í rótarmöppuna </a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Heimildir er venjulega hægt að laga ef %sgefur vefþjóninum skrifréttindi í rótarmöppuna %s.",
    "Setting locale to %s failed" : "Mistókst að setja upp staðfærsluna %s",
    "Please install one of these locales on your system and restart your webserver." : "Settu upp eina af þessum staðfærslum og endurræstu vefþjóninn.",
    "Please ask your server administrator to install the module." : "Biddu kerfisstjórann þinn um að setja eininguna upp.",
    "PHP module %s not installed." : "PHP-einingin %s er ekki uppsett.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-stillingin \"%s\" er ekki sett á \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Breyting á þessari stillingu í php.ini mun gera ownCloud kleift að keyra aftur",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er stillt á \"%s\" í stað gildisins \"0\" eins og vænst var",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Til að laga þetta vandamál ættirðu að setja <code>mbstring.func_overload</code> sem <code>0</code> í php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Krafist er libxml2 2.7.0 hið minnsta. Núna er %s uppsett.",
    "To fix this issue update your libxml2 version and restart your web server." : "Til að laga þetta vandamál ættirðu að uppfæra útgáfu þína af libxml2 og endurræsa vefþjóninn.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Þessu veldur væntanlega biðminni/hraðall á borð við Zend OPcache eða eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Búið er að setja upp PHP-einingar, en eru þær ennþá taldar upp eins og þær vanti?",
    "Please ask your server administrator to restart the web server." : "Biddu kerfisstjórann þinn um að endurræsa vefþjóninn.",
    "PostgreSQL >= 9 required" : "Krefst PostgreSQL >= 9",
    "Please upgrade your database version" : "Uppfærðu útgáfu gagnagrunnsins",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endilega breyttu heimildunum í 0770 svo að aðrir notendur geti ekki listað upp innihald hennar.",
    "Your Data directory is readable by other users" : "Gagnamappan þín er lesanleg fyrir aðra notendur",
    "Your Data directory must be an absolute path" : "Gagnamappan þín verður að vera með algilda slóð",
    "Check the value of \"datadirectory\" in your configuration" : "Athugaðu gildi \"datadirectory\" í uppsetningunni þinni",
    "Your Data directory  is invalid" : "Gagnamappan þín er ógild",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Athugaðu hvort gagnamappan innihaldi skrá með heitinu \".ocdata\" í rót hennar.",
    "Could not obtain lock type %d on \"%s\"." : "Gat ekki fengið læsingu af gerðinni %d á \"%s\".",
    "Storage unauthorized. %s" : "Gagnageymsla ekki auðkennd. %s",
    "Storage incomplete configuration. %s" : "Ófullgerð uppsetning gagnageymslu. %s",
    "Storage connection error. %s" : "Villa í tengingu við gagnageymslu. %s",
    "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
    "Storage connection timeout. %s" : "Gagnageymsla féll á tíma. %s",
    "A safe home for all your data" : "Öruggur stður fyrir öll gögnin þín",
    "The username must be at least 3 characters long" : "Notandanafnið verður að vera að minnsta kosti 3 stafa langt",
    "File cannot be read" : "Ekki hægt að lesa skrána",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Komið hefur í ljós að sýniuppsetningin var afrituð. Þetta getur skemmt uppsetninguna og er ekki stutt. Endilega lestu hjálparskjölin áður en þú gerir breytingar á config.php",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Ekki var hægt að setja upp forritið vegna þess að það inniheldur <shipped>true</shipped>-merki sem ekki er leyfilegt í óútgefnum forritum",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Ekki var hægt að setja upp forritið vegna þess að útgáfan í info.xml er ekki sú sama og gefin er upp í forritabúðinni",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s er ekki stutt og %s mun ekki vinna eðlilega á þessu stýrikerfi. Notaðu þetta því á þína eigin ábyrgð! ",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "Deiling %s mistókst, gat ekki fundið %s, athugaðu stafsetninguna og hvort þjónninn sé tiltækur.",
    "App cannot be installed because appinfo file cannot be read." : "Ekki er hægt að setja upp forritið vegna þess að ekki var hægt að lesa appinfo-skrána.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Ekki var hægt að staðfesta undirritunina. Hafðu samband við forritarana og skoðaðu stjórnskjáinn þinn..",
    "Imprint" : "Prenta",
    "__language_name__" : "Íslenska"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
